"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
import pydantic
from typing import List, Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


ClassificationRequestInputsTypedDict = TypeAliasType(
    "ClassificationRequestInputsTypedDict", Union[str, List[str]]
)
r"""Text to classify."""


ClassificationRequestInputs = TypeAliasType(
    "ClassificationRequestInputs", Union[str, List[str]]
)
r"""Text to classify."""


class ClassificationRequestTypedDict(TypedDict):
    model: str
    r"""ID of the model to use."""
    inputs: ClassificationRequestInputsTypedDict
    r"""Text to classify."""


class ClassificationRequest(BaseModel):
    model: str
    r"""ID of the model to use."""

    inputs: Annotated[ClassificationRequestInputs, pydantic.Field(alias="input")]
    r"""Text to classify."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
import pydantic
from typing import List, Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


InputsTypedDict = TypeAliasType("InputsTypedDict", Union[str, List[str]])
r"""Text to embed."""


Inputs = TypeAliasType("Inputs", Union[str, List[str]])
r"""Text to embed."""


class EmbeddingRequestTypedDict(TypedDict):
    model: str
    r"""ID of the model to use."""
    inputs: InputsTypedDict
    r"""Text to embed."""


class EmbeddingRequest(BaseModel):
    model: str
    r"""ID of the model to use."""

    inputs: Annotated[Inputs, pydantic.Field(alias="input")]
    r"""Text to embed."""



from pydantic import BaseModel
from typing import TypeVar, Any, Type, Dict
from ...models import JSONSchema, ResponseFormat
from ._pydantic_helper import rec_strict_json_schema

CustomPydanticModel = TypeVar("CustomPydanticModel", bound=BaseModel)


def response_format_from_pydantic_model(
    model: Type[CustomPydanticModel],
) -> ResponseFormat:
    """Generate a strict JSON schema from a pydantic model."""
    model_schema = rec_strict_json_schema(model.model_json_schema())
    json_schema = JSONSchema.model_validate(
        {"name": model.__name__, "schema": model_schema, "strict": True}
    )
    return ResponseFormat(type="json_schema", json_schema=json_schema)


def pydantic_model_from_json(
    json_data: Dict[str, Any], pydantic_model: Type[CustomPydanticModel]
) -> CustomPydanticModel:
    """Parse a JSON schema into a pydantic model."""
    return pydantic_model.model_validate(json_data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ocrpageobject import OCRPageObject, OCRPageObjectTypedDict
from .ocrusageinfo import OCRUsageInfo, OCRUsageInfoTypedDict
from mistralai.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class OCRResponseTypedDict(TypedDict):
    pages: List[OCRPageObjectTypedDict]
    r"""List of OCR info for pages."""
    model: str
    r"""The model used to generate the OCR."""
    usage_info: OCRUsageInfoTypedDict


class OCRResponse(BaseModel):
    pages: List[OCRPageObject]
    r"""List of OCR info for pages."""

    model: str
    r"""The model used to generate the OCR."""

    usage_info: OCRUsageInfo



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .contentchunk import ContentChunk, ContentChunkTypedDict
from .toolcall import ToolCall, ToolCallTypedDict
from mistralai_gcp.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


AssistantMessageContentTypedDict = TypeAliasType(
    "AssistantMessageContentTypedDict", Union[str, List[ContentChunkTypedDict]]
)


AssistantMessageContent = TypeAliasType(
    "AssistantMessageContent", Union[str, List[ContentChunk]]
)


AssistantMessageRole = Literal["assistant"]


class AssistantMessageTypedDict(TypedDict):
    content: NotRequired[Nullable[AssistantMessageContentTypedDict]]
    tool_calls: NotRequired[Nullable[List[ToolCallTypedDict]]]
    prefix: NotRequired[bool]
    role: NotRequired[AssistantMessageRole]


class AssistantMessage(BaseModel):
    content: OptionalNullable[AssistantMessageContent] = UNSET

    tool_calls: OptionalNullable[List[ToolCall]] = UNSET

    prefix: Optional[bool] = False

    role: Optional[AssistantMessageRole] = "assistant"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["content", "tool_calls", "prefix", "role"]
        nullable_fields = ["content", "tool_calls"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


TextChunkType = Literal["text"]


class TextChunkTypedDict(TypedDict):
    text: str
    type: NotRequired[TextChunkType]


class TextChunk(BaseModel):
    text: str

    type: Optional[TextChunkType] = "text"



from .struct_chat import ParsedChatCompletionResponse, convert_to_parsed_chat_completion_response
from .utils import response_format_from_pydantic_model
from .utils.response_format import CustomPydanticModel

__all__ = ["convert_to_parsed_chat_completion_response", "response_format_from_pydantic_model", "CustomPydanticModel", "ParsedChatCompletionResponse"]
